@@ -1,23 +1,23 @@
+require "minitest/autorun"
+require "testutil"
 require "openid/consumer/associationmanager"
 require "openid/association"
 require "openid/dh"
 require "openid/util"
 require "openid/cryptutil"
 require "openid/message"
+require "openid/protocolerror"
 require "openid/store/memory"
-require "test/unit"
 require "util"
 require "time"
 
 module OpenID
-  class DHAssocSessionTest < Test::Unit::TestCase
+  class DHAssocSessionTest < Minitest::Test
     def test_sha1_get_request
       # Initialized without an explicit DH gets defaults
       sess = Consumer::DiffieHellmanSHA1Session.new
       assert_equal(['dh_consumer_public'], sess.get_request.keys)
-      assert_nothing_raised do
-        Util::from_base64(sess.get_request['dh_consumer_public'])
-      end
+      Util::from_base64(sess.get_request['dh_consumer_public'])
     end
 
     def test_sha1_get_request_custom_dh
@@ -28,9 +28,7 @@ module OpenID
                    req.keys.sort)
       assert_equal(dh.modulus, CryptUtil.base64_to_num(req['dh_modulus']))
       assert_equal(dh.generator, CryptUtil.base64_to_num(req['dh_gen']))
-      assert_nothing_raised do
-        Util::from_base64(req['dh_consumer_public'])
-      end
+      Util::from_base64(req['dh_consumer_public'])
     end
   end
 
@@ -102,7 +100,7 @@ module OpenID
     end
   end
 
-  class TestConsumerOpenID1DHSHA1 < Test::Unit::TestCase
+  class TestConsumerOpenID1DHSHA1 < Minitest::Test
     include TestDiffieHellmanResponseParametersMixin
     class << self
       attr_reader :session_cls, :message_namespace
@@ -112,7 +110,7 @@ module OpenID
     @message_namespace = OPENID1_NS
   end
 
-  class TestConsumerOpenID2DHSHA1 < Test::Unit::TestCase
+  class TestConsumerOpenID2DHSHA1 < Minitest::Test
     include TestDiffieHellmanResponseParametersMixin
     class << self
       attr_reader :session_cls, :message_namespace
@@ -122,7 +120,7 @@ module OpenID
     @message_namespace = OPENID2_NS
   end
 
-  class TestConsumerOpenID2DHSHA256 < Test::Unit::TestCase
+  class TestConsumerOpenID2DHSHA256 < Minitest::Test
     include TestDiffieHellmanResponseParametersMixin
     class << self
       attr_reader :session_cls, :message_namespace
@@ -132,7 +130,7 @@ module OpenID
     @message_namespace = OPENID2_NS
   end
 
-  class TestConsumerNoEncryptionSession < Test::Unit::TestCase
+  class TestConsumerNoEncryptionSession < Minitest::Test
     def setup
       @sess = Consumer::NoEncryptionSession.new
     end
@@ -149,7 +147,7 @@ module OpenID
     end
   end
 
-  class TestCreateAssociationRequest < Test::Unit::TestCase
+  class TestCreateAssociationRequest < Minitest::Test
     def setup
       @server_url = 'http://invalid/'
       @assoc_manager = Consumer::AssociationManager.new(nil, @server_url)
@@ -203,7 +201,7 @@ module OpenID
 
       # This is a random base-64 value, so just check that it's
       # present.
-      assert_not_nil(args.get_arg(OPENID1_NS, 'dh_consumer_public'))
+      refute_nil(args.get_arg(OPENID1_NS, 'dh_consumer_public'))
       args.del_arg(OPENID1_NS, 'dh_consumer_public')
 
       # OK, session_type is set here and not for no-encryption
@@ -216,7 +214,7 @@ module OpenID
     end
   end
 
-  class TestAssociationManagerExpiresIn < Test::Unit::TestCase
+  class TestAssociationManagerExpiresIn < Minitest::Test
     def expires_in_msg(val)
       msg = Message.from_openid_args({'expires_in' => val})
       Consumer::AssociationManager.extract_expires_in(msg)
@@ -248,7 +246,7 @@ module OpenID
     end
   end
 
-  class TestAssociationManagerCreateSession < Test::Unit::TestCase
+  class TestAssociationManagerCreateSession < Minitest::Test
     def test_invalid
       assert_raises(ArgumentError) {
         Consumer::AssociationManager.create_session('monkeys')
@@ -292,7 +290,7 @@ module OpenID
 
   # Test the session type negotiation behavior of an OpenID 2
   # consumer.
-  class TestOpenID2SessionNegotiation < Test::Unit::TestCase
+  class TestOpenID2SessionNegotiation < Minitest::Test
     include NegotiationTestMixin
 
     Compat = false
@@ -413,7 +411,7 @@ module OpenID
   # oidutil.log.  See the calls to self.failUnlessLogMatches.  Some of
   # these tests pass openid2-style messages to the openid 1
   # association processing logic to be sure it ignores the extra data.
-  class TestOpenID1SessionNegotiation < Test::Unit::TestCase
+  class TestOpenID1SessionNegotiation < Minitest::Test
     include NegotiationTestMixin
 
     Compat = true
@@ -498,7 +496,7 @@ module OpenID
   end
 
 
-  class TestExtractAssociation < Test::Unit::TestCase
+  class TestExtractAssociation < Minitest::Test
     include ProtocolErrorMixin
 
     # An OpenID associate response (without the namespace)
@@ -619,7 +617,7 @@ module OpenID
     end
   end
 
-  class GetOpenIDSessionTypeTest < Test::Unit::TestCase
+  class GetOpenIDSessionTypeTest < Minitest::Test
     include TestUtil
 
     SERVER_URL = 'http://invalid/'
@@ -666,7 +664,7 @@ module OpenID
     end
   end
 
-  class ExtractAssociationTest < Test::Unit::TestCase
+  class ExtractAssociationTest < Minitest::Test
     include ProtocolErrorMixin
 
     SERVER_URL = 'http://invalid/'
@@ -740,7 +738,7 @@ module OpenID
     end
   end
 
-  class TestExtractAssociationDiffieHellman < Test::Unit::TestCase
+  class TestExtractAssociationDiffieHellman < Minitest::Test
     include ProtocolErrorMixin
 
     SECRET = 'x' * 20
@@ -750,7 +748,7 @@ module OpenID
     end
 
     def setup_dh
-      sess, message = @assoc_manager.send(:create_associate_request,
+      sess, _ = @assoc_manager.send(:create_associate_request,
                                           'HMAC-SHA1', 'DH-SHA1')
 
       server_dh = DiffieHellman.new
@@ -799,7 +797,7 @@ module OpenID
     end
   end
 
-  class TestAssocManagerGetAssociation < Test::Unit::TestCase
+  class TestAssocManagerGetAssociation < Minitest::Test
     include FetcherMixin
     include TestUtil
 
@@ -859,7 +857,7 @@ module OpenID
     end
   end
 
-  class TestAssocManagerRequestAssociation < Test::Unit::TestCase
+  class TestAssocManagerRequestAssociation < Minitest::Test
     include FetcherMixin
     include TestUtil
 
