@@ -1,3 +1,4 @@
+require 'minitest/autorun'
 require 'openid/extensions/ax'
 require 'openid/message'
 require 'openid/consumer/responses'
@@ -22,7 +23,7 @@ module OpenID
       end
     end
 
-    class AXMessageTest < Test::Unit::TestCase
+    class AXMessageTest < Minitest::Test
       def setup
         @bax = BogusAXMessage.new
       end
@@ -37,7 +38,7 @@ module OpenID
       end
     end
 
-    class AttrInfoTest < Test::Unit::TestCase
+    class AttrInfoTest < Minitest::Test
       def test_construct
         assert_raises(ArgumentError) { AttrInfo.new }
         type_uri = 'uri geller'
@@ -50,7 +51,7 @@ module OpenID
       end
     end
 
-    class ToTypeURIsTest < Test::Unit::TestCase
+    class ToTypeURIsTest < Minitest::Test
       def setup
         @aliases = NamespaceMap.new
       end
@@ -90,7 +91,7 @@ module OpenID
       end
     end
 
-    class ParseAXValuesTest < Test::Unit::TestCase
+    class ParseAXValuesTest < Minitest::Test
       def ax_values(ax_args, expected_args)
         msg = KeyValueMessage.new
         msg.parse_extension_args(ax_args)
@@ -119,7 +120,7 @@ module OpenID
       def test_invalid_count_value
         msg = FetchRequest.new
         assert_raises(Error) {
-          msg.parse_extension_args({'type.foo'=>'urn:foo', 
+          msg.parse_extension_args({'type.foo'=>'urn:foo',
                                      'count.foo' => 'bogus'})
         }
       end
@@ -216,11 +217,11 @@ module OpenID
                     'value.foo'=>'something',
                   },
                   {'urn:foo'=>['something']}
-                  )     
+                  )
       end
     end
 
-    class FetchRequestTest < Test::Unit::TestCase
+    class FetchRequestTest < Minitest::Test
       def setup
         @msg = FetchRequest.new
         @type_a = 'http://janrain.example.com/a'
@@ -371,12 +372,12 @@ module OpenID
         ax_req = FetchRequest.from_openid_request(openid_req)
         assert(ax_req.nil?)
       end
-      
+
       def test_from_openid_request_wrong_ax_mode
         uri = 'http://under.the.sea/'
         name = 'ext0'
         value = 'snarfblat'
-        
+
         message = OpenID::Message.from_openid_args({
                                                'mode' => 'id_res',
                                                'ns' => OPENID2_NS,
@@ -392,7 +393,7 @@ module OpenID
         ax_req = FetchRequest.from_openid_request(openid_req)
         assert(ax_req.nil?)
       end
-      
+
       def test_openid_update_url_verification_error
         openid_req_msg = Message.from_openid_args({
                                                     'mode' => 'checkid_setup',
@@ -404,7 +405,7 @@ module OpenID
                                                   })
         openid_req = Server::OpenIDRequest.new
         openid_req.message = openid_req_msg
-        assert_raises(Error) { 
+        assert_raises(Error) {
           FetchRequest.from_openid_request(openid_req)
         }
       end
@@ -419,7 +420,7 @@ module OpenID
                                                   })
         openid_req = Server::OpenIDRequest.new
         openid_req.message = openid_req_msg
-        assert_raises(Error) { 
+        assert_raises(Error) {
           FetchRequest.from_openid_request(openid_req)
         }
       end
@@ -482,10 +483,11 @@ module OpenID
       end
     end
 
-    class FetchResponseTest < Test::Unit::TestCase
+    class FetchResponseTest < Minitest::Test
       def setup
         @msg = FetchResponse.new
         @value_a = 'commodity'
+        @value_a1 = 'value2'
         @type_a = 'http://blood.transfusion/'
         @name_a = 'george'
         @request_update_url = 'http://some.url.that.is.awesome/'
@@ -538,12 +540,13 @@ module OpenID
         assert_equal(eargs, @msg.get_extension_args(req))
       end
 
-      def test_get_extension_args_some_request
+      def test_get_extension_args_single_value_response
+        # Single values do NOT have a count, and 
+        # do not use the array extension
         eargs = {
           'mode' => 'fetch_response',
           'type.' + @name_a => @type_a,
-          'value.' + @name_a + '.1' => @value_a,
-          'count.' + @name_a =>  '1'
+          'value.' + @name_a  => @value_a
         }
         req = FetchRequest.new
         req.add(AttrInfo.new(@type_a, @name_a))
@@ -551,6 +554,25 @@ module OpenID
         assert_equal(eargs, @msg.get_extension_args(req))
       end
 
+      def test_get_extension_args_array_value_response
+        # Multiple array values add the count, and array index
+        # to each value
+        eargs = {
+          'mode' => 'fetch_response',
+          'type.' + @name_a => @type_a,
+          'value.' + @name_a + ".1" => @value_a,
+          'value.' + @name_a + ".2" => @value_a1,
+          'count.' + @name_a => '2'
+        }
+        req = FetchRequest.new
+        # Specify that this URI should have a count of 2
+        req.add(AttrInfo.new(@type_a, @name_a, true, 2))
+        # Push both values onto the array
+        @msg.add_value(@type_a, @value_a)
+        @msg.add_value(@type_a, @value_a1)
+        assert_equal(eargs, @msg.get_extension_args(req))
+      end
+
       def test_get_extension_args_some_not_request
         req = FetchRequest.new
         @msg.add_value(@type_a, @value_a)
@@ -558,7 +580,6 @@ module OpenID
       end
 
       def test_get_single_success
-        req = FetchRequest.new
         @msg.add_value(@type_a, @value_a)
         assert_equal(@value_a, @msg.get_single(@type_a))
       end
@@ -572,7 +593,7 @@ module OpenID
         assert_raises(Error) { @msg.get_single(@type_a) }
       end
 
-      def test_from_success_response
+      def test_from_unsigned_success_response
         uri = 'http://under.the.sea/'
         name = 'ext0'
         value = 'snarfblat'
@@ -585,7 +606,7 @@ module OpenID
                                                'ax.mode' => 'fetch_response',
                                                'ax.type.' + name => uri,
                                                'ax.count.' + name => '1',
-                                               'ax.value.' + name + '.1' => value,
+                                               'ax.value.' + name + '.1' => value
                                              })
 
         e = OpenID::OpenIDServiceEndpoint.new()
@@ -597,7 +618,55 @@ module OpenID
         assert_equal(values, [value])
       end
 
-      def test_from_success_response_empty
+      def test_from_signed_success_response
+        uri = 'http://under.the.sea/'
+        name = 'ext0'
+        value = 'snarfblat'
+        oid_fields = {
+          'mode' => 'id_res',
+          'ns' => OPENID2_NS,
+          'ns.ax' => AXMessage::NS_URI,
+          'ax.update_url' => 'http://example.com/realm/update_path',
+          'ax.mode' => 'fetch_response',
+          'ax.type.' + name => uri,
+          'ax.count.' + name => '1',
+          'ax.value.' + name + '.1' => value
+        }
+        signed_fields = oid_fields.keys.map{|f| "openid.#{f}"}
+
+        m = OpenID::Message.from_openid_args(oid_fields)
+        e = OpenID::OpenIDServiceEndpoint.new()
+        resp = OpenID::Consumer::SuccessResponse.new(e, m, signed_fields)
+
+        ax_resp = FetchResponse.from_success_response(resp, true)
+
+        values = ax_resp[uri]
+        assert_equal(values, [value])
+      end
+
+      def test_from_signed_success_response_with_unsigned_attributes
+        uri = 'http://under.the.sea/'
+        name = 'ext0'
+        value = 'snarfblat'
+
+        m = OpenID::Message.from_openid_args({
+                                               'mode' => 'id_res',
+                                               'ns' => OPENID2_NS,
+                                               'ns.ax' => AXMessage::NS_URI,
+                                               'ax.update_url' => 'http://example.com/realm/update_path',
+                                               'ax.mode' => 'fetch_response',
+                                               'ax.type.' + name => uri,
+                                               'ax.count.' + name => '1',
+                                               'ax.value.' + name + '.1' => value
+                                             })
+
+        e = OpenID::OpenIDServiceEndpoint.new()
+        resp = OpenID::Consumer::SuccessResponse.new(e, m, [])
+
+        assert_nil FetchResponse.from_success_response(resp, true)
+      end
+
+      def test_from_empty_success_response
         e = OpenID::OpenIDServiceEndpoint.new()
         m = OpenID::Message.from_openid_args({'mode' => 'id_res'})
         resp = OpenID::Consumer::SuccessResponse.new(e, m, [])
@@ -606,7 +675,7 @@ module OpenID
       end
     end
 
-    class StoreRequestTest < Test::Unit::TestCase
+    class StoreRequestTest < Minitest::Test
       def setup
         @msg = StoreRequest.new
         @type_a = 'http://oranges.are.for/'
@@ -623,12 +692,12 @@ module OpenID
         }
         assert_equal(eargs, @msg.get_extension_args)
       end
-      
+
       def test_from_openid_request_wrong_ax_mode
         uri = 'http://under.the.sea/'
         name = 'ext0'
         value = 'snarfblat'
-        
+
         message = OpenID::Message.from_openid_args({
                                                'mode' => 'id_res',
                                                'ns' => OPENID2_NS,
@@ -644,7 +713,7 @@ module OpenID
         ax_req = StoreRequest.from_openid_request(openid_req)
         assert(ax_req.nil?)
       end
-      
+
       def test_get_extension_args_nonempty
         @msg.set_values(@type_a, ['foo','bar'])
         aliases = NamespaceMap.new
@@ -660,12 +729,12 @@ module OpenID
       end
     end
 
-    class StoreResponseTest < Test::Unit::TestCase
+    class StoreResponseTest < Minitest::Test
       def test_success
         msg = StoreResponse.new
         assert(msg.succeeded?)
         assert(!msg.error_message)
-        assert_equal({'mode' => 'store_response_success'}, 
+        assert_equal({'mode' => 'store_response_success'},
                      msg.get_extension_args)
       end
 
@@ -673,7 +742,7 @@ module OpenID
         msg = StoreResponse.new(false)
         assert(! msg.succeeded? )
         assert(! msg.error_message )
-        assert_equal({'mode' => 'store_response_failure'}, 
+        assert_equal({'mode' => 'store_response_failure'},
                      msg.get_extension_args)
       end
 
@@ -682,7 +751,7 @@ module OpenID
         msg = StoreResponse.new(false, reason)
         assert(! msg.succeeded? )
         assert_equal(reason,  msg.error_message)
-        assert_equal({'mode' => 'store_response_failure', 'error' => reason}, 
+        assert_equal({'mode' => 'store_response_failure', 'error' => reason},
                      msg.get_extension_args)
       end
     end
