@@ -1,8 +1,6 @@
-
+require 'minitest/autorun'
 require 'testutil'
 require 'util'
-
-require 'test/unit'
 require 'openid/fetchers'
 require 'openid/yadis/discovery'
 require 'openid/consumer/discovery'
@@ -28,7 +26,7 @@ module OpenID
     end
   end
 
-  class TestDiscoveryFailure < Test::Unit::TestCase
+  class TestDiscoveryFailure < Minitest::Test
     def initialize(*args)
       super(*args)
 
@@ -48,7 +46,7 @@ module OpenID
       @responses.each { |response_set|
         @url = response_set[0].final_url
         OpenID.fetcher = SimpleMockFetcher.new(self, response_set)
-      
+
         expected_status = response_set[-1].code
         begin
           OpenID.discover(@url)
@@ -82,7 +80,7 @@ module OpenID
     # Custom exception just to make sure it's not handled differently
   end
 
-  class TestFetchException < Test::Unit::TestCase
+  class TestFetchException < Minitest::Test
     # Discovery should only raise DiscoveryFailure
 
     def initialize(*args)
@@ -109,7 +107,7 @@ module OpenID
 
   ### Tests for openid.consumer.discover.discover
 
-  class TestNormalization < Test::Unit::TestCase
+  class TestNormalization < Minitest::Test
     def test_addingProtocol
       f = ErrorRaisingFetcher.new(RuntimeError.new())
       OpenID.fetcher = f
@@ -154,7 +152,7 @@ module OpenID
     end
   end
 
-  class BaseTestDiscovery < Test::Unit::TestCase
+  class BaseTestDiscovery < Minitest::Test
     attr_accessor :id_url, :fetcher_class
 
     def initialize(*args)
@@ -249,7 +247,7 @@ module OpenID
     end
 
     def test_404
-      assert_raise(DiscoveryFailure) {
+      assert_raises(DiscoveryFailure) {
         OpenID.discover(@id_url + '/404')
       }
     end
@@ -384,9 +382,9 @@ module OpenID
     end
 
     def test_yadisEmpty
-      services = _discover('application/xrds+xml',
-                           read_data_file('test_discover/yadis_0entries.xml', false),
-                           0)
+      _discover('application/xrds+xml',
+                read_data_file('test_discover/yadis_0entries.xml', false),
+                0)
     end
 
     def test_htmlEmptyYadis
@@ -477,7 +475,7 @@ module OpenID
     end
 
     def test_yadis2BadLocalID
-      assert_raise(DiscoveryFailure) {
+      assert_raises(DiscoveryFailure) {
         _discover('application/xrds+xml',
                   read_data_file('test_discover/yadis_2_bad_local_id.xml', false),
                   1)
@@ -499,7 +497,7 @@ module OpenID
     end
 
     def test_yadis1And2BadLocalID
-      assert_raise(DiscoveryFailure) {
+      assert_raises(DiscoveryFailure) {
         _discover('application/xrds+xml',
                   read_data_file('test_discover/openid_1_and_2_xrds_bad_delegate.xml', false),
                   1)
@@ -519,7 +517,6 @@ module OpenID
       @fetchlog << [url, body, headers]
 
       u = URI::parse(url)
-      proxy_host = u.host
       xri = u.path
       query = u.query
 
@@ -528,7 +525,7 @@ module OpenID
                                 "mean to do that.")
       end
 
-      if xri.starts_with?('/')
+      if xri.start_with?('/')
         xri = xri[1..-1]
       end
 
@@ -564,7 +561,7 @@ module OpenID
     end
 
     def test_xri
-      user_xri, services = OpenID.discover_xri('=smoker')
+      _, services = OpenID.discover_xri('=smoker')
 
       _checkService(services[0],
                     "http://www.myopenid.com/server",
@@ -586,7 +583,7 @@ module OpenID
     end
 
     def test_xri_normalize
-      user_xri, services = OpenID.discover_xri('xri://=smoker')
+      _, services = OpenID.discover_xri('xri://=smoker')
 
       _checkService(services[0],
                     "http://www.myopenid.com/server",
@@ -609,7 +606,7 @@ module OpenID
 
     def test_xriNoCanonicalID
       silence_logging {
-        user_xri, services = OpenID.discover_xri('=smoker*bad')
+        _, services = OpenID.discover_xri('=smoker*bad')
         assert(services.empty?)
       }
     end
@@ -637,14 +634,14 @@ module OpenID
     end
 
     def test_xri
-      user_xri, services = OpenID.discover_xri('=smoker')
+      _, services = OpenID.discover_xri('=smoker')
       assert(!services.empty?, "Expected services, got zero")
       assert_equal(services[0].server_url,
                    "http://www.livejournal.com/openid/server.bml")
     end
   end
 
-  class TestPreferredNamespace < Test::Unit::TestCase
+  class TestPreferredNamespace < Minitest::Test
     def initialize(*args)
       super(*args)
 
@@ -673,7 +670,7 @@ module OpenID
     end
   end
 
-  class TestIsOPIdentifier < Test::Unit::TestCase
+  class TestIsOPIdentifier < Minitest::Test
     def setup
       @endpoint = OpenIDServiceEndpoint.new()
     end
@@ -716,7 +713,7 @@ module OpenID
     end
   end
 
-  class TestFromOPEndpointURL < Test::Unit::TestCase
+  class TestFromOPEndpointURL < Minitest::Test
     def setup
       @op_endpoint_url = 'http://example.com/op/endpoint'
       @endpoint = OpenIDServiceEndpoint.from_op_endpoint_url(@op_endpoint_url)
@@ -744,18 +741,14 @@ module OpenID
     end
   end
 
-  class TestDiscoverFunction < Test::Unit::TestCase
+  class TestDiscoverFunction < Minitest::Test
     def test_discover_function
       # XXX these were all different tests in python, but they're
       # combined here so I only have to use with_method_overridden
       # once.
-      discoverXRI = Proc.new { |identifier|
-        return 'XRI'
-      }
+      discoverXRI = Proc.new { |identifier| 'XRI' }
 
-      discoverURI = Proc.new { |identifier|
-        return 'URI'
-      }
+      discoverURI = Proc.new { |identifier| 'URI' }
 
       OpenID.extend(OverrideMethodMixin)
 
@@ -770,7 +763,7 @@ module OpenID
     end
   end
 
-  class TestEndpointSupportsType < Test::Unit::TestCase
+  class TestEndpointSupportsType < Minitest::Test
     def setup
       @endpoint = OpenIDServiceEndpoint.new()
     end
@@ -833,7 +826,7 @@ module OpenID
     end
   end
 
-  class TestEndpointDisplayIdentifier < Test::Unit::TestCase
+  class TestEndpointDisplayIdentifier < Minitest::Test
     def test_strip_fragment
       @endpoint = OpenIDServiceEndpoint.new()
       @endpoint.claimed_id = 'http://recycled.invalid/#123'
@@ -842,9 +835,9 @@ module OpenID
   end
 
 
-  class TestNormalizeURL < Test::Unit::TestCase
+  class TestNormalizeURL < Minitest::Test
     def test_no_host
-      assert_raise(DiscoveryFailure) {
+      assert_raises(DiscoveryFailure) {
         OpenID::normalize_url('http:///too-many.invalid/slashes')
       }
     end
